@@ -1,4 +1,4 @@
-from stock import Stock
+from jamesbot.stock import Stock
 
 class DataLoarder():
     
